@@ -327,12 +327,12 @@ class Jenkins():
     def get_url(self, group_name, repository_name):
         return f"{self.base_url}/project/{group_name}/{repository_name}"
 
-    def create_job(self, group_name, repository_name, description, gitlab_url, gitlab_repository_name):
+    def create_job(self, group_name, repository_name, description, gitlab_url, gitlab_repository_name, jenkins_credential):
         repository_full_name = f"{group_name}/{repository_name}"
-        config = self.get_default_job_config(gitlab_url, group_name, repository_name, description, gitlab_repository_name)
+        config = self.get_default_job_config(gitlab_url, group_name, repository_name, description, gitlab_repository_name, jenkins_credential)
         self.jnks.create_job(repository_full_name, config)
 
-    def get_default_job_config(self, gitlab_url, group_name, repository_name, description, gitlab_repository_name):
+    def get_default_job_config(self, gitlab_url, group_name, repository_name, description, gitlab_repository_name, jenkins_credential):
         DEFAULT_CONFIG = """<?xml version='1.1' encoding='UTF-8'?>
 <flow-definition plugin="workflow-job@2.42">
   <actions>
@@ -421,7 +421,7 @@ class Jenkins():
       <userRemoteConfigs>
         <hudson.plugins.git.UserRemoteConfig>
           <url>{gitlab_url}/{repository}.git</url>
-          <credentialsId>cs_jenkins_gitlab_personal_access_token</credentialsId>
+          <credentialsId>{credential}</credentialsId>
         </hudson.plugins.git.UserRemoteConfig>
       </userRemoteConfigs>
       <branches>
@@ -447,4 +447,5 @@ class Jenkins():
             repository=gitlab_repository_name,
             description=description,
             token="{AQAAABAAAAAwn0PMV7WTFCnRSkwbTfvm7603mkro7e+5PvP0NTkPaQIr4W1q6U2c6FvDwBq3Uq+PV3zDPI4vRD+YohxEdVgxRg==}",
-            gitlab_url=gitlab_url)
\ No newline at end of file
+            gitlab_url=gitlab_url,
+            credential=jenkins_credential)
\ No newline at end of file
