@@ -738,9 +738,16 @@ class Quip:
 
             gl_groups = gl_config.get("groups", [])
             jnks_groups = jnks_config.get("groups", {})
-            jnks_group_name, jnks_repository_name = external.parse_repository_full_path(repository_name, gl_groups, jnks_groups)
-            
-            self.setup_jenkins(jnks, jnks_group_name, jnks_repository_name, gl.base_url, repository_name)
+            jnks_group_details, jnks_repository_name = external.parse_repository_full_path(repository_name, gl_groups, jnks_groups)
+            jnks_group_name = jenkins_credential = None
+            if jnks_group_details:
+                if isinstance(jnks_group_details, str):
+                    jnks_group_name = jnks_group_details
+                    jenkins_credential = "cs_prototype_api_personal_access_token"
+                elif isinstance(jnks_group_details, dict):
+                    jnks_group_name = jnks_group_details["name"]
+                    jenkins_credential = jnks_group_details["credential"]
+            self.setup_jenkins(jnks, jnks_group_name, jnks_repository_name, gl.base_url, repository_name, jenkins_credential)
             
         # create webhook for Jenkins
         if gl_config is not None and jnks_config is not None:
@@ -784,7 +791,7 @@ class Quip:
         gl.repository_name = repository_name
         return gl
     
-    def setup_jenkins(self, jnks, jnks_group_name, jnks_repository_name, gitlab_url, repository_name):
+    def setup_jenkins(self, jnks, jnks_group_name, jnks_repository_name, gitlab_url, repository_name, jenkins_credential):
         logging.debug(f"Group: {jnks_group_name}, Repository: {jnks_repository_name}")
         # Check if Jenkins Pipeline exists
         if jnks.check_job_exists(jnks_group_name, jnks_repository_name):
@@ -792,7 +799,7 @@ class Quip:
         else:
             logging.info(f"Repository doesn't exist and will be created. {jnks_group_name}/{jnks_repository_name}")
             if yes_or_no("Do you want to create Jenkins Job?", default=True):
-                jnks.create_job(jnks_group_name, jnks_repository_name, self.project_name, gitlab_url, repository_name)
+                jnks.create_job(jnks_group_name, jnks_repository_name, self.project_name, gitlab_url, repository_name, jenkins_credential)
                 cprint(f"Jenkins job created: {jnks_group_name}/{jnks_repository_name}", "green")
 
     def create_sonarqube(self, group_name, repository_name, sq_config):
